@@ -65,7 +65,7 @@ class MinVersions(object):
     GSTREAMER = Version("GStreamer", 1, 8)
 
 
-VERSION_TUPLE = Version("", 4, 1, 0)
+VERSION_TUPLE = Version("", 4, 2, 0)
 VERSION = str(VERSION_TUPLE)
 
 # entry point for the user guide / wiki
@@ -82,7 +82,7 @@ SUPPORT_EMAIL = "quod-libet-development@googlegroups.com"
 
 # about dialog, --version etc.
 WEBSITE = "https://quodlibet.readthedocs.org/"
-COPYRIGHT = u"Copyright 2004-2017"
+COPYRIGHT = u"Copyright 2004-2018"
 
 AUTHORS = sorted(u"""\
 Alexandre Passos
@@ -93,6 +93,7 @@ Andreas Bombe
 Andrew Chadwick
 Anton Shestakov
 Ari Pollak
+Arkadiy Illarionov
 Aymeric Mansoux
 Bastian Kleineidam
 Bastien Gorissen
@@ -105,14 +106,17 @@ Christine Spang
 Christoph Reiter
 Corentin Néau
 David Kågedal
+David Morris
 David Schneider
 Decklin Foster
 Didier Villevalois
 Eduardo Gonzalez
+Eoin O'Neill
 Eric Casteleijn
 Erich Schubert
 Eric Le Lay
 Federico Pelloni
+Felicián Németh
 Felix Krull
 Florian Demmer
 Fredrik Strupe
@@ -121,6 +125,7 @@ Hans Scholze
 Iñigo Serna
 Jacob Lee
 Jakob Gahde
+Jakub Wilk
 Jan Arne Petersen
 Jan Path
 Javier Kohen
@@ -135,6 +140,7 @@ Joshua Homan
 Joshua Kwan
 Lalo Martins
 Lee Willis
+Ludovic Druette
 Lukáš Lalinský
 Markus Koller
 Martijn Pieters
@@ -146,8 +152,12 @@ Nicholas J. Michalek
 Nick Boultbee
 Niklas Janlert
 Nikolai Prokoschenko
+Olli Helin
+Peter Simonyi
+Peter Strulo
 Philipp Müller
 Philipp Weis
+Phoenix Dailey
 Quincy John Hamilton
 Remi Vanicat
 Robert Muth
@@ -183,12 +193,11 @@ Meriipu@github
 Jonas Platte
 Eyenseo@github
 Peter Simonyi
+dpitch40@github
+sphh@github
 zsau@github
+luk1337@github
 luzpaz@github
-Tom McCleery
-archy3@github
-Felician Nemeth
-David Morris
 """.strip().split("\n"))
 
 TRANSLATORS = sorted(u"""
@@ -246,12 +255,13 @@ Yasushi Iwata (ja)
 Николай Прокошенко (ru)
 Ростислав "zbrox" Райков (bg)
 Сергей Федосеев (ru)
-scootergrisen@github (da)
+scootergrisen (da)
 Marek Suchánek (cs)
 Till Berger (de)
 Jean-Michel Pouré (fr)
 Kristian Laakkonen (fi)
 Kirill Romanov (ru)
+wvxwxvw@github (ru)
 """.strip().splitlines())
 
 ARTISTS = sorted(u"""\
@@ -264,4 +274,8 @@ Fabien Devaux
 DEFAULT_COLUMNS = "~#track ~people ~title~version ~album~discsubtitle " \
                   "~#length".split()
 
+COLUMN_MODE_SMALL = "Small"
+COLUMN_MODE_WIDE = "Wide"
+COLUMN_MODE_COLUMNAR = "Columnar"
+
 DEBUG = ("--debug" in sys.argv or "QUODLIBET_DEBUG" in os.environ)
